
from distutils.core import setup

setup(

       name = 'ishanaapurba',
       version = '1.0.0',
       py_modules = ['ishanaapurba'],
       author = 'Abhishek Kashyap',
       author_email = 'aabhishek2010@gmail.com',
       url = 'http://www.headfirstlabs.com',
       description = 'A simple printer of listed items',

    )
